@@ -1,4 +1,4 @@
-# Copyright (c) 2018 - 2023 Advanced Micro Devices, Inc. All rights reserved.
+# Copyright (c) 2018 - 2025 Advanced Micro Devices, Inc. All rights reserved.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -28,7 +28,7 @@ import rocal_pybind as b
 from amd.rocal.pipeline import Pipeline
 
 
-def image(*inputs, user_feature_key_map=None, path='', file_root='', annotations_file='', shard_id=0, num_shards=1, random_shuffle=False,
+def image(*inputs, user_feature_key_map=None, path='', file_root='', annotations_file='', index_path ='', shard_id=0, num_shards=1, random_shuffle=False,
           output_type=types.RGB, decoder_type=types.DECODER_TJPEG, device=None,
           decode_size_policy=types.USER_GIVEN_SIZE_ORIG, max_decoded_width=1000, max_decoded_height=1000,
           last_batch_policy=types.LAST_BATCH_FILL, pad_last_batch=True, stick_to_shard=True, shard_size=-1):
@@ -43,7 +43,7 @@ def image(*inputs, user_feature_key_map=None, path='', file_root='', annotations
         @param num_shards               Total number of shards for parallel processing.
         @param random_shuffle           Whether to shuffle images randomly.
         @param output_type              Color format of the output image.
-        @param decoder_type             Type of image decoder to use.
+        @param decoder_type             Type of image decoder to use - TurboJpeg, OpenCV or rocJpeg
         @param device                   Device to use for decoding ("gpu" or "cpu").
         @param decode_size_policy       Size policy for decoding images.
         @param max_decoded_width        Maximum width for decoded images.
@@ -56,9 +56,7 @@ def image(*inputs, user_feature_key_map=None, path='', file_root='', annotations
     sharding_info = b.RocalShardingInfo(last_batch_policy, pad_last_batch, stick_to_shard, shard_size)
 
     if (device == "gpu"):
-        decoder_type = types.DECODER_HW_JEPG
-    else:
-        decoder_type = types.DECODER_TJPEG
+        decoder_type = types.DECODER_ROCJPEG
     if (reader == 'COCOReader'):
         kwargs_pybind = {
             "source_path": file_root,
@@ -145,7 +143,23 @@ def image(*inputs, user_feature_key_map=None, path='', file_root='', annotations
             "sharding_info": sharding_info}
         decoded_image = b.mxnetDecoder(
             Pipeline._current_pipeline._handle, *(kwargs_pybind.values()))
-
+    elif reader == "WebDataset":
+        kwargs_pybind = {
+            "source_path": file_root,
+            "index_path": index_path,
+            "output_type": output_type,
+            "shard_id": shard_id,
+            "num_shards": num_shards,
+            'is_output': False,
+            "shuffle": random_shuffle,
+            "loop": False,
+            "decode_size_policy": decode_size_policy,
+            "max_width": max_decoded_width,
+            "max_height": max_decoded_height,
+            "dec_type": decoder_type,
+            "sharding_info": sharding_info}
+        decoded_image = b.webdatasetSourceSingleShard(
+            Pipeline._current_pipeline._handle, *(kwargs_pybind.values()))
     else:
         kwargs_pybind = {
             "source_path": file_root,
@@ -326,7 +340,7 @@ def image_random_crop(*inputs, user_feature_key_map=None, path='', file_root='',
     return (crop_output_image)
 
 
-def image_slice(*inputs, file_root='', path='', annotations_file='', shard_id=0, num_shards=1, random_shuffle=False,
+def image_slice(*inputs, file_root='', path='', annotations_file='', shard_id=0, num_shards=1, random_shuffle=False, device = 'cpu',
                 random_aspect_ratio=[0.75, 1.33333], random_area=[0.08, 1.0], num_attempts=100, output_type=types.RGB,
                 decode_size_policy=types.USER_GIVEN_SIZE_ORIG, max_decoded_width=1000, max_decoded_height=1000, last_batch_policy=types.LAST_BATCH_FILL, pad_last_batch=True, stick_to_shard=True, shard_size=-1):
     """!Slices images randomly using different readers and decoders.
@@ -351,14 +365,17 @@ def image_slice(*inputs, file_root='', path='', annotations_file='', shard_id=0,
     reader = Pipeline._current_pipeline._reader
     Pipeline._current_pipeline._last_batch_policy = last_batch_policy
     sharding_info = b.RocalShardingInfo(last_batch_policy, pad_last_batch, stick_to_shard, shard_size)
-
+    
+    if (device == "gpu"):
+        decoder_type = types.DECODER_ROCJPEG
+    else:
+        decoder_type = types.DECODER_TJPEG
     # Reader -> Randon BBox Crop -> ImageDecoderSlice
     # Random crop parameters taken from pytorch's RandomResizedCrop default function arguments
     # TODO:To pass the crop co-ordinates from random_bbox_crop to image_slice
     # in tensor branch integration,
     # for now calling partial decoder to match SSD training outer API's .
     if (reader == 'COCOReader'):
-
         kwargs_pybind = {
             "source_path": file_root,
             "json_path": annotations_file,
@@ -374,7 +391,8 @@ def image_slice(*inputs, file_root='', path='', annotations_file='', shard_id=0,
             "decode_size_policy": decode_size_policy,
             "max_width": max_decoded_width,
             "max_height": max_decoded_height,
-            "sharding_info": sharding_info}
+            "sharding_info": sharding_info,
+            "dec_type": decoder_type}
         image_decoder_slice = b.cocoImageDecoderSliceShard(
             Pipeline._current_pipeline._handle, *(kwargs_pybind.values()))
     elif (reader == "CaffeReader" or reader == "CaffeReaderDetection"):
@@ -392,7 +410,8 @@ def image_slice(*inputs, file_root='', path='', annotations_file='', shard_id=0,
             "decode_size_policy": decode_size_policy,
             "max_width": max_decoded_width,
             "max_height": max_decoded_height,
-            "sharding_info": sharding_info}
+            "sharding_info": sharding_info,
+            "dec_type": decoder_type}
         image_decoder_slice = b.caffeImageDecoderPartialShard(
             Pipeline._current_pipeline._handle, *(kwargs_pybind.values()))
     elif (reader == "Caffe2Reader" or reader == "Caffe2ReaderDetection"):
@@ -410,7 +429,8 @@ def image_slice(*inputs, file_root='', path='', annotations_file='', shard_id=0,
             "decode_size_policy": decode_size_policy,
             "max_width": max_decoded_width,
             "max_height": max_decoded_height,
-            "sharding_info": sharding_info}
+            "sharding_info": sharding_info,
+            "dec_type": decoder_type}
         image_decoder_slice = b.caffe2ImageDecoderPartialShard(
             Pipeline._current_pipeline._handle, *(kwargs_pybind.values()))
     else:
@@ -428,7 +448,8 @@ def image_slice(*inputs, file_root='', path='', annotations_file='', shard_id=0,
             "decode_size_policy": decode_size_policy,
             "max_width": max_decoded_width,
             "max_height": max_decoded_height,
-            "sharding_info": sharding_info}
+            "sharding_info": sharding_info,
+            "dec_type": decoder_type}
         image_decoder_slice = b.fusedDecoderCropShard(
             Pipeline._current_pipeline._handle, *(kwargs_pybind.values()))
     return (image_decoder_slice)
@@ -474,3 +495,4 @@ def audio(*inputs, file_root='', file_list_path='', bytes_per_sample_hint=[0], s
     Pipeline._current_pipeline._last_batch_policy = last_batch_policy
     decoded_audio = b.audioDecoderSingleShard(Pipeline._current_pipeline._handle, *(kwargs_pybind.values()))
     return decoded_audio
+
